pub enum ColumnUsage {
Unknown,
Known(HashSet<String>),
}Expand description
Enum storing info on which dataset columns are used in a given context. Due to the dynamic nature of Vega specifications, it’s not always possible to statically determine which columns from a dataset will be used at runtime. In this case the ColumnUsage::Unknown variant is used. In the context of projection pushdown, the ColumnUsage::Unknown variant indicates that all of original dataset columns must be maintained
Variants
Implementations
Sourceimpl ColumnUsage
impl ColumnUsage
pub fn empty() -> ColumnUsage
pub fn with_column(&self, column: &str) -> ColumnUsage
Sourcepub fn union(&self, other: &ColumnUsage) -> ColumnUsage
pub fn union(&self, other: &ColumnUsage) -> ColumnUsage
Take the union of two ColumnUsage instances. If both are ColumnUsage::Known, then take the union of their known columns. If either is ColumnUsage::Unknown, then the union is also Unknown.
pub fn difference(&self, other: &ColumnUsage) -> ColumnUsage