pub enum TransformColumns {
PassThrough {
usage: DatasetsColumnUsage,
produced: ColumnUsage,
},
Overwrite {
usage: DatasetsColumnUsage,
produced: ColumnUsage,
},
Unknown,
}Variants
PassThrough
Transforms that pass through existing columns and produce zero or more new columns
Overwrite
Transforms that overwrite all input columns, leaving only those produced by the transform
Unknown
Transforms with unknown usage and/or production of columns